
#include "SPI.h"
#ifdef MSP430
	#include  "msp430x20x2.h"
#endif

#ifdef STM32
	#include "stm32f10x.h"
#endif

void delay_clk(unsigned int delay)
{
    while(delay) delay--;   
}

void init_spi(void)
{
    sclk_0;
    CS_1;   
}


void write_spi (unsigned char data_out)
{       //msb first
    unsigned char mask;
    for (mask=0x80; mask; mask=mask>>1)
    {
        sclk_0;
        if (data_out & mask)
        {
        	mosi_1;
        }
        else mosi_0;
        sclk_1;
    }
    sclk_0;
}

unsigned char read_spi (void)
{       //msb first
    unsigned char ucTemp = 0;
    unsigned char ucCounter = 0;
    mosi_1;     //DummyByte 0xFF
    for (ucCounter=0; ucCounter!=8; ucCounter++)
    {
        sclk_0;
        delay_clk(delay_value);
        sclk_1;
        if (miso) ucTemp = (ucTemp | 0x01);
        else ucTemp = ucTemp & 0xFE;
        if(ucCounter < 7) ucTemp = ucTemp << 1;
    }
    sclk_0;
    return ucTemp;
}

unsigned char read_write_spi(unsigned char data_out)
{
    unsigned char ucTemp = 0;
    unsigned char mask;
    unsigned char ucCounter = 0;
    for (mask=0x80; mask; mask=mask>>1)
    {
        sclk_0;
        delay_clk(delay_value);
        if (data_out & mask)
        {
        	mosi_1;
        }
        else mosi_0;
        sclk_1;
        delay_clk(delay_value);
        if (miso) ucTemp = (ucTemp | 0x01);
        else ucTemp = ucTemp & 0xFE;
        if(ucCounter < 7) ucTemp = ucTemp << 1;
        ucCounter++;
    }
    sclk_0;
    return ucTemp;

}

unsigned char spiSendFrame(unsigned char* pBuffer, unsigned int size)
{
  unsigned long i = 0;
  // clock the actual data transfer and receive the bytes; spi_read automatically finds the Data Block
  for (i = 0; i < size; i++){
	 pBuffer[i] = read_write_spi(pBuffer[i]);     // write
  }
  return(0);
}

//Read a frame of bytes via SPI
unsigned char spiReadFrame(unsigned char* pBuffer, unsigned int size)
{
  unsigned long i = 0;
  // clock the actual data transfer and receive the bytes; spi_read automatically finds the Data Block
  for (i = 0; i < size; i++){
    pBuffer[i] = read_write_spi(0xFF);
  }
  return(0);
}



